@@ -90,7 +90,7 @@ def print_version(ctx, param, value):
     default=None,
     type=int,
     help="Number of worker processes. Defaults to the $WEB_CONCURRENCY environment"
-    " variable if available. Not valid with --reload.",
+    " variable if available, or 1. Not valid with --reload.",
 )
 @click.option(
     "--loop",
@@ -355,7 +355,7 @@ def main(
         "ssl_cert_reqs": ssl_cert_reqs,
         "ssl_ca_certs": ssl_ca_certs,
         "ssl_ciphers": ssl_ciphers,
-        "headers": list([header.split(":", 1) for header in headers]),
+        "headers": [header.split(":", 1) for header in headers],
         "use_colors": use_colors,
         "factory": factory,
     }
